
#ifndef _C1_et46_
#define _C1_et46_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_REFERENCE F69_954(EIF_REFERENCE, EIF_INTEGER_32);
extern void EIF_Minit46(void);
extern void F1260_13495(EIF_REFERENCE);
extern void F1261_13651(EIF_REFERENCE, EIF_INTEGER_32);

#ifdef __cplusplus
}
#endif

#endif
